Class: Aws::KendraRanking::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KendraRanking::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kendraranking/client.rb,
sig/client.rbs
Overview
An API client for KendraRanking. To construct a client, you need to configure a :region and :credentials.
client = Aws::KendraRanking::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateRescoreExecutionPlanResponseSuccess, _DescribeRescoreExecutionPlanResponseSuccess, _ListRescoreExecutionPlansResponseSuccess, _ListTagsForResourceResponseSuccess, _RescoreResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_rescore_execution_plan(params = {}) ⇒ Types::CreateRescoreExecutionPlanResponse
Creates a rescore execution plan.
-
#delete_rescore_execution_plan(params = {}) ⇒ Struct
Deletes a rescore execution plan.
-
#describe_rescore_execution_plan(params = {}) ⇒ Types::DescribeRescoreExecutionPlanResponse
Gets information about a rescore execution plan.
-
#list_rescore_execution_plans(params = {}) ⇒ Types::ListRescoreExecutionPlansResponse
Lists your rescore execution plans.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a specified resource.
-
#rescore(params = {}) ⇒ Types::RescoreResult
Rescores or re-ranks search results from a search service such as OpenSearch (self managed).
-
#tag_resource(params = {}) ⇒ Struct
Adds a specified tag to a specified rescore execution plan.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a rescore execution plan.
-
#update_rescore_execution_plan(params = {}) ⇒ Struct
Updates a rescore execution plan.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-kendraranking/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
916 917 918 |
# File 'lib/aws-sdk-kendraranking/client.rb', line 916 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
919 920 921 |
# File 'lib/aws-sdk-kendraranking/client.rb', line 919 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 |
# File 'lib/aws-sdk-kendraranking/client.rb', line 889 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KendraRanking') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kendraranking' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_rescore_execution_plan(params = {}) ⇒ Types::CreateRescoreExecutionPlanResponse
Creates a rescore execution plan. A rescore execution plan is an
Amazon Kendra Intelligent Ranking resource used for provisioning the
Rescore API. You set the number of capacity units that you require
for Amazon Kendra Intelligent Ranking to rescore or re-rank a search
service's results.
For an example of using the CreateRescoreExecutionPlan API,
including using the Python and Java SDKs, see Semantically ranking a
search service's results.
88 |
# File 'sig/client.rbs', line 88
def create_rescore_execution_plan: (
|
#delete_rescore_execution_plan(params = {}) ⇒ Struct
Deletes a rescore execution plan. A rescore execution plan is an
Amazon Kendra Intelligent Ranking resource used for provisioning the
Rescore API.
105 |
# File 'sig/client.rbs', line 105
def delete_rescore_execution_plan: (
|
#describe_rescore_execution_plan(params = {}) ⇒ Types::DescribeRescoreExecutionPlanResponse
Gets information about a rescore execution plan. A rescore execution
plan is an Amazon Kendra Intelligent Ranking resource used for
provisioning the Rescore API.
123 |
# File 'sig/client.rbs', line 123
def describe_rescore_execution_plan: (
|
#list_rescore_execution_plans(params = {}) ⇒ Types::ListRescoreExecutionPlansResponse
Lists your rescore execution plans. A rescore execution plan is an
Amazon Kendra Intelligent Ranking resource used for provisioning the
Rescore API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
134 |
# File 'sig/client.rbs', line 134
def list_rescore_execution_plans: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a specified resource. A rescore execution plan is an example of a resource that can have tags associated with it.
145 |
# File 'sig/client.rbs', line 145
def list_tags_for_resource: (
|
#rescore(params = {}) ⇒ Types::RescoreResult
Rescores or re-ranks search results from a search service such as OpenSearch (self managed). You use the semantic search capabilities of Amazon Kendra Intelligent Ranking to improve the search service's results.
156 |
# File 'sig/client.rbs', line 156
def rescore: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a specified tag to a specified rescore execution plan. A rescore
execution plan is an Amazon Kendra Intelligent Ranking resource used
for provisioning the Rescore API. If the tag already exists, the
existing value is replaced with the new value.
177 |
# File 'sig/client.rbs', line 177
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a rescore execution plan. A rescore execution plan
is an Amazon Kendra Intelligent Ranking resource used for provisioning
the Rescore operation.
192 |
# File 'sig/client.rbs', line 192
def untag_resource: (
|
#update_rescore_execution_plan(params = {}) ⇒ Struct
Updates a rescore execution plan. A rescore execution plan is an
Amazon Kendra Intelligent Ranking resource used for provisioning the
Rescore API. You can update the number of capacity units you require
for Amazon Kendra Intelligent Ranking to rescore or re-rank a search
service's results.
199 |
# File 'sig/client.rbs', line 199
def update_rescore_execution_plan: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
909 910 911 |
# File 'lib/aws-sdk-kendraranking/client.rb', line 909 def waiter_names [] end |